@@ -57,7 +57,7 @@ class ScoreAPI:
     def setUpScore(self, uuid):
         # If it's a new day, or if the uuid hasn't existed, reset the score.
         score_dict = self.getScores()
-        if score_dict[3] != datetime.datetime.now().date() or uuid not in score_dict:
+        if uuid not in score_dict or score_dict[3] != datetime.datetime.now().date():
             score_dict[uuid] = (0, 0, 0, datetime.datetime.now().date())
             self.writeToFile(score_dict)
     
